<?php
/**
 * @file bcc.admin.inc
 * Settings for for the BCC module.
 */

/**
 * Return the settings form.
 *
 * Form to enable BCC and specify an email address that should be injected.
 */
function bcc_admin_settings() {
  $form['bcc_mail'] = array(
    '#type' => 'checkbox',
    '#title' => t('Send Blind Carbon Copy'),
    '#description' => t('Choose whether you want Drupal to add a blind carbon copy to all e-mail its sends.'),
    '#default_value' => variable_get('bcc_mail', 0),
  );
  $form['bcc_mail_address'] = array(
    '#type' => 'textfield',
    '#title' => t('E-mail address'),
    '#description' => t('Enter the e-mail address that should receive copies of all site e-mails. You may also enter multiple e-mail addresses separated by commas.'),
    '#default_value' => variable_get('bcc_mail_address', variable_get('site_mail', '')),
  );

  $form['bcc_mail_visibility'] = array(
    '#type' => 'radios',
    '#title' => t('BCC mail with specific mail IDs'),
    '#options' => array(
      BCC_EXCLUDE_ID => t('All mail IDs except those listed'),
      BCC_INCLUDE_ID => t('Only the listed mail IDs'),
    ),
    '#default_value' => variable_get('bcc_mail_visibility', BCC_EXCLUDE_ID),
  );
  $form['bcc_mail_id'] = array(
    '#type' => 'textarea',
    '#title' => t('BCC mail IDs'),
    '#description' => t("Specify system mails by using their IDs. Enter one ID per line. The '*' character is a wildcard. Example IDs are %user_register_no_approval_required for the account creation notification email and %user_password_reset for the password reset email.", array('%user_register_no_approval_required' => 'user_register_no_approval_required', '%user_password_reset' => 'user_password_reset')),
    '#default_value' => variable_get('bcc_mail_id', ''),
  );
  return system_settings_form($form);
}

/**
 * Validate handler for the settings form.
 */
function bcc_admin_settings_validate(&$form, $form_state) {
  if ($form_state['values']['bcc_mail']) {
    // Split multiple addresses on commas
    $recipients = explode(',', $form_state['values']['bcc_mail_address']);
    foreach ($recipients as $recipient) {
      // Trim each in case there is a space before or after commas
      if (!valid_email_address(trim($recipient))) {
        // Report an error on each failed address
        form_set_error('bcc_mail_address', t('@addr is not a valid e-mail address', array('@addr' => $recipient)));
      }
    }
  }
  // Tidy up the list of IDs.
  $form_state['values']['bcc_mail_id'] = trim($form_state['values']['bcc_mail_id']);
}
